@@ -282,7 +282,7 @@ fn path_applicable_imports(
                 //
                 // see also an ignored test under FIXME comment in the qualify_path.rs module
                 AssocItemSearch::Exclude,
-                Some(DEFAULT_QUERY_SEARCH_LIMIT),
+                Some(DEFAULT_QUERY_SEARCH_LIMIT.inner()),
             )
             .filter_map(|item| {
                 let mod_path = mod_path(item)?;
@@ -299,7 +299,7 @@ fn path_applicable_imports(
                 current_crate,
                 path_candidate.name.clone(),
                 AssocItemSearch::Include,
-                Some(DEFAULT_QUERY_SEARCH_LIMIT),
+                Some(DEFAULT_QUERY_SEARCH_LIMIT.inner()),
             )
             .filter_map(|item| {
                 import_for_item(
@@ -445,7 +445,7 @@ fn trait_applicable_items(
         current_crate,
         trait_candidate.assoc_item_name.clone(),
         AssocItemSearch::AssocItemsOnly,
-        Some(DEFAULT_QUERY_SEARCH_LIMIT),
+        Some(DEFAULT_QUERY_SEARCH_LIMIT.inner()),
     )
     .filter_map(|input| item_as_assoc(db, input))
     .filter_map(|assoc| {
